@@ -56,13 +56,26 @@ textmodel_lsa.tokens <- function(x, dim = 50L, min_count = 5L,
                                  engine = c("RSpectra", "irlba", "rsvd"), 
                                  weight = "count", verbose = FALSE, ...) {
     
+    result <- textmodel_lsa(dfm(x, remove_padding = TRUE), 
+                            dim = dim, min_count = min_count, engine = engine, weight = weight,
+                            verbose = verbose, ...)
+    result$call = try(match.call(sys.function(-1), call = sys.call(-1)), silent = TRUE)
+    return(result)
+}
+
+#' @import quanteda
+#' @export
+#' @method textmodel_lsa dfm
+textmodel_lsa.dfm <- function(x, dim = 50L, min_count = 5L, 
+                                 engine = c("RSpectra", "irlba", "rsvd"), 
+                                 weight = "count", verbose = FALSE, ...) {
+    
     engine <- match.arg(engine)
     dim <- check_integer(dim, min = 2)
     min_count <- check_integer(min_count, min = 0)
     verbose <- check_logical(verbose)
     
-    x <- tokens_trim(x, min_termfreq = min_count, termfreq_type = "count")
-    x <- dfm(x, remove_padding = TRUE)
+    x <- dfm_trim(x, min_termfreq = min_count, termfreq_type = "count")
     if (engine %in% c("RSpectra", "irlba", "rsvd")) {
         if (verbose) {
             cat(sprintf("Performing SVD into %d dimensions\n", dim))
